/*************************************************************************/
/* libsurl - library for generating shortened URLs                       */
/* Copyright (C) 2009  Scott Lawrence <bytbox@gmail.com> et al.          */
/*                                                                       */
/* This program is free software: you can redistribute it and/or modify  */
/* it under the terms of the GNU General Public License as published by  */
/* the Free Software Foundation, either version 3 of the License, or (at */
/* your option) any later version.                                       */
/*                                                                       */
/* This program is distributed in the hope that it will be useful, but   */
/* WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     */
/* General Public License for more details.                              */
/*                                                                       */
/* You should have received a copy of the GNU General Public License     */
/* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/*************************************************************************/

//main.c - main test file for libsurl

#include <stdlib.h>
#include <stdio.h>

#include <libsurl-fe.h>

inline void done() {
    puts("done!");
}

int main(int argc,char *argv[]) {
    printf("Running tests for libsurl...\n");

    printf("Creating... ");
    fflush(stdout);
    SURL *surl=surl_init();
    if(surl==0) return 1;
    done();
    
    printf("Setting options... ");
    fflush(stdout);
    surl_setopt(surl,SURLOPT_URL,"https://launchpad.net/libsurl");
    surl_setopt(surl,SURLOPT_SERVICE,BIT_LY);
    surl_setopt(surl,SURLOPT_USERNAME,"libsurl");
    surl_setopt(surl,SURLOPT_API_KEY,"R_d23d5fe4eea3777446ec7fa17d67bf42");
    char *c=surl_getopt(surl,SURLOPT_URL);
    if(strcmp(c,"https://launchpad.net/libsurl"))
        return 1;
    done();

    char *services[]={
        /*        A_GD,
        A_NF,
        BIT_LY,
        BURNURL,
        CHILP_IT,
        CLI_GS,
        DECENTURL,
        DIGG,
        IS_GD,
        KL_AM,
        KURL_IT,
        LIIP_TO,
        METAMARK,
        PIURL,
        RI_MS,
        SN_IM,
        SNIPR,
        SNIPURL,
        SNURL,
        SRNK_NET,
        TINY_CC,
        TINYURL,
        TR_IM,
        TURL_CA,
        TWURL_NL,
        UR_LY,
        ZI_MA,
        ZZ_GD,*/
        YIT_ME,
        NOTLONG,
        URLOF,
        0
    };
    //snipr API is 66e75e21e1e322cc22f71ddd06208acd
    surl_setopt(surl,SURLOPT_API_KEY,"66e75e21e1e322cc22f71ddd06208acd");
    int i=0;
    //    surl_debug_on(surl);
    while(services[i]!=0) {
        surl_setopt(surl,SURLOPT_SERVICE,services[i]);
        surl_shorten(surl);
        surl_wait(surl);
        printf("%s: ",services[i]);
        puts(surl_getopt(surl,SURLOPT_SHORT_URL));
        fflush(stdout);
        i++;
        if(surl_get_error(surl))
            printf("Error: %d\n",surl_get_error(surl));
        surl_reset_error(surl);
        if(surl_debug(surl))
            puts("");
    }

    printf("Cleaning up... ");
    fflush(stdout);
    surl_cleanup(surl);
    done();

    return 0;
}
